# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`ccs_software`](#ccs_software): Installs and configures CCS software

#### Private Classes

* `ccs_software::config`: Install /etc/ccs files.
* `ccs_software::desktop`: Add desktop menu entries for CCS apps.
* `ccs_software::install`: Install ccs software.
* `ccs_software::log`: Create /var/log/ccs and install logrotation.
* `ccs_software::pre`: Install ccs software prerequisites
* `ccs_software::service`: Manages ccs systemd service units

## Classes

### <a name="ccs_software"></a>`ccs_software`

Installs and configures CCS software

#### Parameters

The following parameters are available in the `ccs_software` class:

* [`installations`](#-ccs_software--installations)
* [`service_workdir`](#-ccs_software--service_workdir)
* [`services`](#-ccs_software--services)
* [`base_path`](#-ccs_software--base_path)
* [`etc_path`](#-ccs_software--etc_path)
* [`log_path`](#-ccs_software--log_path)
* [`user`](#-ccs_software--user)
* [`group`](#-ccs_software--group)
* [`adm_user`](#-ccs_software--adm_user)
* [`adm_group`](#-ccs_software--adm_group)
* [`influx_url`](#-ccs_software--influx_url)
* [`influx_name`](#-ccs_software--influx_name)
* [`influx_username`](#-ccs_software--influx_username)
* [`influx_password`](#-ccs_software--influx_password)
* [`kafka_files`](#-ccs_software--kafka_files)
* [`kafka_auths`](#-ccs_software--kafka_auths)
* [`service_email`](#-ccs_software--service_email)
* [`pkglist_repo_url`](#-ccs_software--pkglist_repo_url)
* [`release_repo_url`](#-ccs_software--release_repo_url)
* [`release_repo_ref`](#-ccs_software--release_repo_ref)
* [`env`](#-ccs_software--env)
* [`hostname`](#-ccs_software--hostname)
* [`desktop`](#-ccs_software--desktop)
* [`git_force`](#-ccs_software--git_force)
* [`global_properties`](#-ccs_software--global_properties)
* [`udp_properties`](#-ccs_software--udp_properties)

##### <a name="-ccs_software--installations"></a>`installations`

Data type: `Hash[String, Hash]`

Hash of hashes which describes one or more CCS "installations" to manage.

Options:

* **name-of-installation** `String`: The top level hash keys are the name of the installation. Eg., `foo` would
create the installation `/opt/lsst/ccs/<foo>`.

Supported keys in nested hashes:

- repo_path - Overrides the default path to package list repo clone for this installation.
- repo_url - Overrides the `pkglist_repo_url` param for this installation.
- repo_ref - Overrides the `pkglist_repo_ref` param for this installation.
- env - Overides the `env` param for this installation.
- hostname - Overides the `hostname` param for this installation.
- aliases - [Array] of "alias" links to create for the current installation.

Default value: `{}`

##### <a name="-ccs_software--service_workdir"></a>`service_workdir`

Data type: `Optional[String]`

CWD for services

Default value: `undef`

##### <a name="-ccs_software--services"></a>`services`

Data type: `Hash[String, Array[Variant[String, Hash]]]`

Hash of Arrays of services to create systemd service units for.

Options:

* **name-of-alias** `String`: [Array] of service names/service executables (links under /opt/lsst/<alias>/bin/)
Alternatively, array element can also be a hash of the form
{ name: "h2db", key: "value", ... }
Allowed keys: cmd, user, group, workdir, env, enable.
Values specify the associated service file values/state.

Default value: `{}`

##### <a name="-ccs_software--base_path"></a>`base_path`

Data type: `Stdlib::Absolutepath`

Base path for [all] CCS installations.

Default value: `'/opt/lsst'`

##### <a name="-ccs_software--etc_path"></a>`etc_path`

Data type: `Stdlib::Absolutepath`

Path to global CCS configuration files.

Default value: `'/etc/ccs'`

##### <a name="-ccs_software--log_path"></a>`log_path`

Data type: `Stdlib::Absolutepath`

Path to CCS log files.

Default value: `'/var/log/ccs'`

##### <a name="-ccs_software--user"></a>`user`

Data type: `String`

Name of the role user under which CCS services will be run and the owner of config files

Default value: `'ccs'`

##### <a name="-ccs_software--group"></a>`group`

Data type: `String`

Name of the role group

Default value: `'ccs'`

##### <a name="-ccs_software--adm_user"></a>`adm_user`

Data type: `String`

Name of the admin role user which owns many of the installed files

Default value: `'ccsadm'`

##### <a name="-ccs_software--adm_group"></a>`adm_group`

Data type: `String`

Name of the admin role group

Default value: `'ccsadm'`

##### <a name="-ccs_software--influx_url"></a>`influx_url`

Data type: `String[1]`

String giving URL of the influxDB server.

Default value: `'https://camera-influxdb.dev.lsst.org:443'`

##### <a name="-ccs_software--influx_name"></a>`influx_name`

Data type: `String[1]`

String giving name of the influxDB instance.

Default value: `'grafana'`

##### <a name="-ccs_software--influx_username"></a>`influx_username`

Data type: `Sensitive[String[1]]`

Sensitive string giving influxDB username.

Default value: `Sensitive('user')`

##### <a name="-ccs_software--influx_password"></a>`influx_password`

Data type: `Sensitive[String[1]]`

Sensitive string giving influxDB password.

Default value: `Sensitive('pass')`

##### <a name="-ccs_software--kafka_files"></a>`kafka_files`

Data type: `Hash[String, Hash]`

Optional hash of kafka properties files and associated values. Eg:
  data-int:
    bootstrap_url: "bootstrap_url"
    registry_url: "registry_url"

Default value: `{}`

##### <a name="-ccs_software--kafka_auths"></a>`kafka_auths`

Data type: `Hash[String, Array[Variant[Sensitive[String],String]]]`

Optional (but required for each key of kafka_files) hash of kafka
files and the associated username and password. Eg:
  data-int:
    - "user"
    - "pass"

Default value: `{}`

##### <a name="-ccs_software--service_email"></a>`service_email`

Data type: `String`

String giving email address (or comma separated addresses) to
receive change of service status emails from systemd.

Default value: `'root@localhost'`

##### <a name="-ccs_software--pkglist_repo_url"></a>`pkglist_repo_url`

Data type: `Stdlib::HTTPUrl`

URL of the git repo to use for `install.py` package lists by default.  This
may be overriden in a `installations` hash with the `repo_url` key.

Default value: `'https://github.com/lsst-camera-dh/dev-package-lists'`

##### <a name="-ccs_software--release_repo_url"></a>`release_repo_url`

Data type: `Stdlib::HTTPUrl`

URL of the repo which contains the `install.py` script.

Default value: `'https://github.com/lsst-it/release'`

##### <a name="-ccs_software--release_repo_ref"></a>`release_repo_ref`

Data type: `String`

`install.py` git repo ref.

Default value: `'IT-4348/python3'`

##### <a name="-ccs_software--env"></a>`env`

Data type: `Optional[String]`

Name of the package list environment.  Eg., `ComCam`.  This may be
overriden in a `installation` hash with the `env` key.

Default value: `undef`

##### <a name="-ccs_software--hostname"></a>`hostname`

Data type: `Optional[String]`

The "short" hostname used to select the installation set in a package lists repo.

Default value: `$facts['networking']['hostname']`

##### <a name="-ccs_software--desktop"></a>`desktop`

Data type: `Boolean`

Install desktop shortcuts.

Default value: `false`

##### <a name="-ccs_software--git_force"></a>`git_force`

Data type: `Boolean`

Force the update of managed git clones. This is done by passing `force =>
true` to `vcsrepo` type resources.

Default value: `false`

##### <a name="-ccs_software--global_properties"></a>`global_properties`

Data type: `Array[String]`

Array of extra strings to add to the ccsGlobal.properties file.

Default value: `[]`

##### <a name="-ccs_software--udp_properties"></a>`udp_properties`

Data type: `Array[String]`

Array of extra strings to add to the udp_ccs.properties file.

Default value: `[]`

